@@ -1,5 +1,4 @@
 # Script to read the Lahman data base .csv files & create Rdata files
-# updated by Chris Dalzell for Lahman 3.0, incorporating 2013 data
 
 # directory where the .csv files will be created
 indir <- "D:/Dev/R/Lahman/data"
@@ -8,9 +7,16 @@ indir <- "D:/Dev/R/Lahman/data"
 #outdir <- paste0(indir, "RData")
 outdir <- indir
 
-zipfile <- "http://seanlahman.com/files/database/lahman-csv_2014-02-14.zip"
-download.file(zipfile, "./lahman-csv_2014-02-14.zip")
-unzip("./lahman-csv_2014-02-14.zip", exdir=indir)
+# local data location
+dataFile <- "./lahman-csv_2015-01-24.zip"
+
+# no need to download if we already have the file
+if (!file.exists(dataFile)) {
+  zipfile <- "http://seanlahman.com/files/database/lahman-csv_2015-01-24.zip"
+  download.file(zipfile, dataFile)
+}
+
+unzip(dataFile, exdir=indir)
 
 setwd(indir)
 
@@ -18,12 +24,12 @@ setwd(indir)
 #Batting <- read.csv(file="Batting.csv", header=TRUE, stringsAsFactors=FALSE, na.strings="")
 #Master <- read.csv(file="Master.csv", header=TRUE, stringsAsFactors=FALSE)
 
-(files <- list.files(path=indir, pattern="*.csv"))
+(files <- list.files(path=indir, pattern="*.csv$"))
 
 for (i in 1:length(files)) {
 	inp <- read.csv(file=files[i], header=TRUE, stringsAsFactors=FALSE, na.strings="")
 	cat("Read:", files[i], "\trows: ", nrow(inp), " cols: ", ncol(inp), "\n")
-	
+
 	# make a few variables factors
 	if("lgID" %in% names(inp)) inp$lgID <- factor(inp$lgID)
 	if("teamID" %in% names(inp)) inp$teamID <- factor(inp$teamID)
@@ -35,10 +41,10 @@ for (i in 1:length(files)) {
 	if("lgIDloser" %in% names(inp)) inp$lgIDloser <- factor(inp$lgIDloser)
 	if("teamIDwinner" %in% names(inp)) inp$teamIDwinner <- factor(inp$teamIDwinner)
 	if("teamIDloser" %in% names(inp)) inp$teamIDloser <- factor(inp$teamIDloser)
-	
+
 	cname <- name <- sub(".csv", "", files[i])
 	assign( name, inp)
-	
+  
 	save(inp, file=paste(cname, ".RData", sep=""))
 #	promptData(inp, name=cname)
 }
@@ -51,7 +57,7 @@ colnames(HallOfFame)[2] <- 'yearID'
 
 # $ debut       : chr  "4/13/1954 0:00:00" "4/10/1962 0:00:00" "7/26/1977 0:00:00" "9/10/2001 0:00:00" ...
 # $ finalGame   : chr  "10/3/1976 0:00:00" "9/26/1971 0:00:00" "10/3/1990 0:00:00" "4/13/2006 0:00:00" ...
-
+ 
 ##################
 # Convert debut/finalGame from character to Date class
 # The format in the as.Date() function is the 'informat', 
@@ -64,13 +70,13 @@ Master <- within(Master, {
 #    finalGame = as.Date(finalGame, 
 #                        format = '%m/%d/%Y %H:%M:%s',
 #                        origin = '1970-01-01')
-			birthDate = as.Date(paste(birthYear, birthMonth, birthDay, sep = '-'),
-					format = '%Y-%m-%d')
-			deathDate = as.Date(paste(deathYear, deathMonth, deathDay, sep = '-'),
-					format = '%Y-%m-%d')
-			bats = factor(bats)
-			throws = factor(throws)
-		}  )
+   birthDate = as.Date(paste(birthYear, birthMonth, birthDay, sep = '-'),
+                       format = '%Y-%m-%d')
+   deathDate = as.Date(paste(deathYear, deathMonth, deathDay, sep = '-'),
+                       format = '%Y-%m-%d')
+   bats = factor(bats)
+   throws = factor(throws)
+}  )
 
 #* checking data for non-ASCII characters ... WARNING
 #  Warning: found non-ASCII string(s)
@@ -94,7 +100,8 @@ save(AwardsPlayers,       file="AwardsPlayers.RData")
 save(AwardsShareManagers, file="AwardsShareManagers.RData")
 save(AwardsSharePlayers,  file="AwardsSharePlayers.RData") 
 save(Batting,             file="Batting.RData")            
-save(BattingPost,         file="BattingPost.RData")        
+save(BattingPost,         file="BattingPost.RData")
+save(CollegePlaying,      file="CollegePlaying.RData")
 save(Fielding,            file="Fielding.RData")           
 save(FieldingOF,          file="FieldingOF.RData")         
 save(FieldingPost,        file="FieldingPost.RData")       
@@ -107,7 +114,7 @@ save(Pitching,            file="Pitching.RData")
 save(PitchingPost,        file="PitchingPost.RData")       
 save(Salaries,            file="Salaries.RData")           
 save(Schools,             file="Schools.RData")            
-save(SchoolsPlayers,      file="SchoolsPlayers.RData")     
+#save(SchoolsPlayers,      file="SchoolsPlayers.RData")
 save(SeriesPost,          file="SeriesPost.RData")         
 save(Teams,               file="Teams.RData")              
 save(TeamsFranchises,     file="TeamsFranchises.RData")    
@@ -116,32 +123,32 @@ save(TeamsHalf,           file="TeamsHalf.RData")
 
 # only ran this once, since all .Rd files were extensively edited
 if (FALSE) {
-	promptData(Allstar,             filename="Allstar.Rd")            
-	promptData(AllstarFull,         filename="AllstarFull.Rd")        
-	promptData(Appearances,         filename="Appearances.Rd")        
-	promptData(AwardsManagers,      filename="AwardsManagers.Rd")     
-	promptData(AwardsPlayers,       filename="AwardsPlayers.Rd")      
-	promptData(AwardsShareManagers, filename="AwardsShareManagers.Rd")
-	promptData(AwardsSharePlayers,  filename="AwardsSharePlayers.Rd") 
-	promptData(Batting,             filename="Batting.Rd")            
-	promptData(BattingPost,         filename="BattingPost.Rd")        
-	promptData(Fielding,            filename="Fielding.Rd")           
-	promptData(FieldingOF,          filename="FieldingOF.Rd")         
-	promptData(FieldingPost,        filename="FieldingPost.Rd")       
-	promptData(HallOfFame,          filename="HallOfFame.Rd")         
-	promptData(HOFold,              filename="HOFold.Rd")             
-	promptData(Managers,            filename="Managers.Rd")           
-	promptData(ManagersHalf,        filename="ManagersHalf.Rd")       
-	promptData(Master,              filename="Master.Rd")             
-	promptData(Pitching,            filename="Pitching.Rd")           
-	promptData(PitchingPost,        filename="PitchingPost.Rd")       
-	promptData(Salaries,            filename="Salaries.Rd")           
-	promptData(Schools,             filename="Schools.Rd")            
-	promptData(SchoolsPlayers,      filename="SchoolsPlayers.Rd")     
-	promptData(SeriesPost,          filename="SeriesPost.Rd")         
-	promptData(Teams,               filename="Teams.Rd")              
-	promptData(TeamsFranchises,     filename="TeamsFranchises.Rd")    
-	promptData(TeamsHalf,           filename="TeamsHalf.Rd")          
-	promptData(Xref_Stats,          filename="Xref_Stats.Rd")         
+promptData(Allstar,             filename="Allstar.Rd")            
+promptData(AllstarFull,         filename="AllstarFull.Rd")        
+promptData(Appearances,         filename="Appearances.Rd")        
+promptData(AwardsManagers,      filename="AwardsManagers.Rd")     
+promptData(AwardsPlayers,       filename="AwardsPlayers.Rd")      
+promptData(AwardsShareManagers, filename="AwardsShareManagers.Rd")
+promptData(AwardsSharePlayers,  filename="AwardsSharePlayers.Rd") 
+promptData(Batting,             filename="Batting.Rd")            
+promptData(BattingPost,         filename="BattingPost.Rd")
+promptData(CollegePlaying,      filename="CollegePlaying.Rd") 
+promptData(Fielding,            filename="Fielding.Rd")           
+promptData(FieldingOF,          filename="FieldingOF.Rd")         
+promptData(FieldingPost,        filename="FieldingPost.Rd")       
+promptData(HallOfFame,          filename="HallOfFame.Rd")         
+promptData(HOFold,              filename="HOFold.Rd")             
+promptData(Managers,            filename="Managers.Rd")           
+promptData(ManagersHalf,        filename="ManagersHalf.Rd")       
+promptData(Master,              filename="Master.Rd")             
+promptData(Pitching,            filename="Pitching.Rd")           
+promptData(PitchingPost,        filename="PitchingPost.Rd")       
+promptData(Salaries,            filename="Salaries.Rd")           
+promptData(Schools,             filename="Schools.Rd")
+promptData(SeriesPost,          filename="SeriesPost.Rd")         
+promptData(Teams,               filename="Teams.Rd")              
+promptData(TeamsFranchises,     filename="TeamsFranchises.Rd")    
+promptData(TeamsHalf,           filename="TeamsHalf.Rd")          
+promptData(Xref_Stats,          filename="Xref_Stats.Rd")         
 }
 
